==> moodle-1.8.4.tgz: moodle/lang/en_utf8/message.php <==
<?PHP // $Id: message.php,v 1.5.2.2 2007/11/22 01:03:30 toyomoyo Exp $ 
      // message.php - created with Moodle 1.7 beta + (2006101003)


$string['addcontact'] = 'Add contact';
$string['addsomecontacts'] = 'To send a message to someone, or to add a shortcut for them on this page, use the <a href=\"$a\">search tab</a> above.';
$string['addsomecontactsincoming'] = 'These messages are from people who are not in your contact list. To add them to your contacts, click the \"Add contact\" icon next to their name.';
$string['ago'] = '$a ago';
$string['allmine'] = 'All messages to me or from me';
$string['allstudents'] = 'All messages between students in course';
$string['allusers'] = 'All messages from all users';
$string['backupmessageshelp'] = 'If enabled, then instant messages will be included in SITE automated backups';
$string['beepnewmessage'] = 'Beep when a new message comes in (may require browser plugin that can play sounds, such as Quicktime)';
$string['blockcontact'] = 'Block contact';
$string['blockedmessages'] = '$a message(s) to/from blocked users';
$string['blocknoncontacts'] = 'Block all new messages from people who are not on my contact list';
$string['contactlistempty'] = 'Your contact list is currently empty';
$string['contacts'] = 'Contacts';
$string['context'] = 'context';
$string['deletemessagesdays'] = 'Number of days before old messages are automatically deleted';
$string['discussion'] = 'Discussion';
$string['emailmessages'] = 'Email messages when I am offline';
$string['emailtagline'] = 'This email is a copy of a message sent to you at \"$a\"';
$string['emptysearchstring'] = 'You must search for something';
$string['formorethan'] = 'For more than';
$string['includeblockedusers'] = 'Include blocked users';
$string['incomingcontacts'] = 'Incoming Contacts ($a)';
$string['keywords'] = 'Keywords';
$string['keywordssearchresults'] = 'Search results: $a messages found';
$string['maxmessages'] = 'Maximum number of messages to show in the discussion history';
$string['message'] = 'Message';
$string['messagehistory'] = 'Message History';
$string['messages'] = 'Messages';
$string['messaging'] = 'Messaging';
$string['messagingdisabled'] = 'Messaging is disabled on this site, emails will be sent instead';
$string['mycontacts'] = 'My Contacts';
$string['newsearch'] = 'New search';
$string['newonlymsg'] = 'Show only new';
$string['noframesjs'] = 'Version without frames and JavaScript';
$string['nomessages'] = 'No messages waiting';
$string['nomessagesfound'] = 'No messages were found';
$string['nosearchresults'] = 'There were no results from your search';
$string['offline'] = 'Offline';
$string['offlinecontacts'] = 'Offline Contacts ($a)';
$string['online'] = 'Online';
$string['onlinecontacts'] = 'Online Contacts ($a)';
$string['onlyfromme'] = 'Only messages from me';
$string['onlymycourses'] = 'Only in my courses';
$string['onlytome'] = 'Only messages to me';
$string['pagerefreshes'] = 'This page refreshes automatically every $a seconds';
$string['readmessages'] = '$a read messages';
$string['removecontact'] = 'Remove contact';
$string['savemysettings'] = 'Save my settings';
$string['search'] = 'Search';
$string['searchforperson'] = 'Search for a person';
$string['searchmessages'] = 'Search messages';
$string['sendmessage'] = 'Send message';
$string['sendmessageto'] = 'Send message to $a';
$string['sendmessagetopopup'] = 'Send message to $a - new window';
$string['settings'] = 'Settings';
$string['settingssaved'] = 'Your settings have been saved';
$string['showmessagewindow'] = 'Automatically show Message window when I get new messages (your browser needs to be set so that it doesn\'t block popups on this site)';
$string['strftimedaydatetime'] = '%%A, %%d %%B %%Y, %%I:%%M %%p';
$string['timenosee'] = 'Minutes since I was last seen online';
$string['timesent'] = 'Time Sent';
$string['unblockcontact'] = 'Unblock contact';
$string['unreadmessages'] = '$a unread messages';
$string['userisblockingyou'] = 'This user has blocked you from sending messages to them';
$string['userisblockingyounoncontact'] = 'This user is only accepting messages from people listed as contacts, and you are not currently on the list.';
$string['userssearchresults'] = 'Search results: $a users found';

?>

==> moodle-1.9.16p0.tgz: moodle/lang/en_utf8/message.php <==
<?PHP // $Id: message.php,v 1.7.2.1 2007/11/22 01:04:59 toyomoyo Exp $ 
      // message.php - created with Moodle 1.7 beta + (2006101003)


$string['addcontact'] = 'Add contact';
$string['addsomecontacts'] = 'To send a message to someone, or to add a shortcut for them on this page, use the <a href=\"$a\">search tab</a> above.';
$string['addsomecontactsincoming'] = 'These messages are from people who are not in your contact list. To add them to your contacts, click the \"Add contact\" icon next to their name.';
$string['ago'] = '$a ago';
$string['allmine'] = 'All messages to me or from me';
$string['allstudents'] = 'All messages between students in course';
$string['allusers'] = 'All messages from all users';
$string['backupmessageshelp'] = 'If enabled, then instant messages will be included in SITE automated backups';
$string['beepnewmessage'] = 'Beep when a new message comes in (may require browser plugin that can play sounds, such as Quicktime)';
$string['blockcontact'] = 'Block contact';
$string['blockedmessages'] = '$a message(s) to/from blocked users';
$string['blocknoncontacts'] = 'Block all new messages from people who are not on my contact list';
$string['contactlistempty'] = 'Your contact list is currently empty';
$string['contacts'] = 'Contacts';
$string['context'] = 'context';
$string['deletemessagesdays'] = 'Number of days before old messages are automatically deleted';
$string['discussion'] = 'Discussion';
$string['emailmessages'] = 'Email messages when I am offline';
$string['emailtagline'] = 'This email is a copy of a message sent to you at \"$a\"';
$string['emptysearchstring'] = 'You must search for something';
$string['formorethan'] = 'For more than';
$string['includeblockedusers'] = 'Include blocked users';
$string['incomingcontacts'] = 'Incoming Contacts ($a)';
$string['keywords'] = 'Keywords';
$string['keywordssearchresults'] = 'Search results: $a messages found';
$string['maxmessages'] = 'Maximum number of messages to show in the discussion history';
$string['mailsent'] = 'Your message was sent via email.';
$string['message'] = 'Message';
$string['messagehistory'] = 'Message History';
$string['messages'] = 'Messages';
$string['messaging'] = 'Messaging';
$string['messagingdisabled'] = 'Messaging is disabled on this site, emails will be sent instead';
$string['mycontacts'] = 'My Contacts';
$string['newsearch'] = 'New search';
$string['newonlymsg'] = 'Show only new';
$string['noframesjs'] = 'Version without frames and JavaScript';
$string['nomessages'] = 'No messages waiting';
$string['nomessagesfound'] = 'No messages were found';
$string['nosearchresults'] = 'There were no results from your search';
$string['offline'] = 'Offline';
$string['offlinecontacts'] = 'Offline Contacts ($a)';
$string['online'] = 'Online';
$string['onlinecontacts'] = 'Online Contacts ($a)';
$string['onlyfromme'] = 'Only messages from me';
$string['onlymycourses'] = 'Only in my courses';
$string['onlytome'] = 'Only messages to me';
$string['pagerefreshes'] = 'This page refreshes automatically every $a seconds';
$string['readmessages'] = '$a read messages';
$string['removecontact'] = 'Remove contact';
$string['savemysettings'] = 'Save my settings';
$string['search'] = 'Search';
$string['searchforperson'] = 'Search for a person';
$string['searchmessages'] = 'Search messages';
$string['sendmessage'] = 'Send message';
$string['sendmessageto'] = 'Send message to $a';
$string['sendmessagetopopup'] = "Send message to \$a - new window";
$string['settings'] = 'Settings';
$string['settingssaved'] = 'Your settings have been saved';
$string['showmessagewindow'] = 'Automatically show Message window when I get new messages (your browser needs to be set so that it doesn\'t block popups on this site)';
$string['strftimedaydatetime'] = '%%A, %%d %%B %%Y, %%I:%%M %%p';
$string['timenosee'] = 'Minutes since I was last seen online';
$string['timesent'] = 'Time Sent';
$string['unblockcontact'] = 'Unblock contact';
$string['unreadmessages'] = '$a unread messages';
$string['userisblockingyou'] = 'This user has blocked you from sending messages to them';
$string['userisblockingyounoncontact'] = 'This user is only accepting messages from people listed as contacts, and you are not currently on the list.';
$string['userssearchresults'] = 'Search results: $a users found';

?>
